trm.cline
=========

trm.cline handles parameter input for Python scripts, interpreting
those entered on the command line, and internally prompting for those
not given according to names defined within the scripts. It uses disk
files to save the parameter values so that they can be recalled as
defaults on next invocation, potentially saving much typing. It also
allows multiple scripts to share parameters.

Install with::

 pip install .

or::

 pip install . --user

if you don't have root access.

* Free software: BSD license

